@@ -7,9 +7,9 @@ from uuid import UUID
 
 import yarl
 
+from . import DDDStructure
 from .core import Nothing, BaseDDDMessage
 from ..abstract import AbstractField
-from . import DDDStructure
 
 T = t.TypeVar('T')
 
@@ -60,6 +60,9 @@ class Field(AbstractField, t.Generic[T]):
         return self._serialize(value)
 
     def _serialize(self, value: T):  # pragma: no cover
+        if value is None:
+            return None
+
         return str(value)
 
     def raise_type_error(self, value):
@@ -105,6 +108,9 @@ class Uuid(Field):
         self.raise_type_error(value)
 
     def _serialize(self, value):
+        if value is None:
+            return None
+
         return str(value)
 
 
@@ -121,7 +127,7 @@ class Integer(Field):
             pass
         self.raise_type_error(value)
 
-    def _serialize(self, value: int):
+    def _serialize(self, value: t.Optional[int]):
         return value
 
 
@@ -136,7 +142,7 @@ class Float(Field):
             pass
         self.raise_type_error(value)
 
-    def _serialize(self, value: float):
+    def _serialize(self, value: t.Optional[float]):
         return value
 
 
@@ -161,7 +167,10 @@ class Decimal(Field):
             pass
         self.raise_type_error(value)
 
-    def _serialize(self, value):
+    def _serialize(self, value: t.Optional[decimal.Decimal]):
+        if value is None:
+            return None
+
         return str(value)
 
 
@@ -228,7 +237,7 @@ class Boolean(Field):
             pass
         self.raise_type_error(value)
 
-    def _serialize(self, value: T):
+    def _serialize(self, value: t.Optional[T]):
         return value
 
 
@@ -242,7 +251,10 @@ class Datetime(Field):
             return value.astimezone(timezone.utc)
         self.raise_type_error(value)
 
-    def _serialize(self, value):
+    def _serialize(self, value: t.Optional[datetime]):
+        if value is None:
+            return None
+
         return value.isoformat()
 
 
@@ -256,7 +268,10 @@ class Time(Field):
             return value
         self.raise_type_error(value)
 
-    def _serialize(self, value: time):
+    def _serialize(self, value: t.Optional[time]):
+        if value is None:
+            return None
+
         return value.isoformat()
 
 
@@ -270,7 +285,10 @@ class Date(Field):
             return value
         self.raise_type_error(value)
 
-    def _serialize(self, value: date):
+    def _serialize(self, value: t.Optional[date]):
+        if value is None:
+            return None
+
         return value.isoformat()
 
 
@@ -352,6 +370,9 @@ class List(Field):
         return tuple(result)
 
     def _serialize(self, value):
+        if value is None:
+            return None
+
         result = []
         for item in value:
             result.append(self.instance.serialize(item))
@@ -374,4 +395,5 @@ class Structure(Field):
     def _serialize(self, value: t.Optional[DDDStructure]):
         if value is None:
             return None
+
         return value.dump()
